==> samba-4.0.3.tar.gz: samba-4.0.3/source4/scripting/devel/selftest-vars.sh <==
# . these into your shell to allow you to run with socketwrapper
# outside the test environment

export UID_WRAPPER=1
export NSS_WRAPPER_PASSWD=$PWD/st/dc/passwd
export NSS_WRAPPER_GROUP=$PWD/st/dc/group
export CONFIGURATION="--configfile=$PWD/st/dc/etc/smb.conf"
export VAMPIRE_DC_SERVER=localvampiredc
export VAMPIRE_DC_SERVER_IP=127.0.0.22
export VAMPIRE_DC_NETBIOSNAME=localvampiredc1
export VAMPIRE_DC_NETBIOSALIAS=localvampiredc
export MEMBER_SERVER=localmember3
export MEMBER_SERVER_IP=127.0.0.23
export MEMBER_NETBIOSNAME=localmember3
export MEMBER_NETBIOSALIAS=localmember
export RPC_PROXY_SERVER=localrpcproxy4
export RPC_PROXY_SERVER_IP=127.0.0.24
export RPC_PROXY_NETBIOSNAME=localrpcproxy4
export RPC_PROXY_NETBIOSALIAS=localrpcproxy
export SELFTEST_MAXTIME=1200
export NETBIOSNAME=localdc1
export REALM=SAMBA.EXAMPLE.COM
export SOCKET_WRAPPER_DEFAULT_IFACE=21
export SERVER=localdc1
export WINBINDD_SOCKET_DIR=$PWD/st/dc/winbindd_socket
export SELFTEST_PREFIX=$PWD/st
export DOMAIN=SAMBADOMAIN
export BINDIR=./bin
export DC_SERVER_IP=127.0.0.21
export SELFTEST_INTERFACES=127.0.0.6/8,127.0.0.7/8,127.0.0.8/8,127.0.0.9/8,127.0.0.10/8,127.0.0.11/8
export SOCKET_WRAPPER_DIR=$PWD/st/w
export DC_USERNAME=Administrator
export USERNAME=Administrator
export SERVER_IP=127.0.0.21
export KRB5_CONFIG=$PWD/st/dc/etc/krb5.conf
export PREFIX_ABS=$PWD/st
export SRCDIR_ABS=$PWD
export PREFIX=$PWD/st
export KRB5CCNAME=$PWD/st/krb5ticket
export SRCDIR=$PWD/
export TLS_ENABLED=yes
export DC_NETBIOSALIAS=localdc
export DC_NETBIOSNAME=localdc1
export DC_SERVER=localdc1
export DC_PASSWORD=locDCpass1
export PYTHONPATH=$PWD/bin/python
export PASSWORD=locDCpass1
export NETBIOSALIAS=localdc
export SMB_CONF_PATH=$PWD/st/dc/etc/smb.conf

==> samba-4.2.2.tar.gz: samba-4.2.2/source4/scripting/devel/selftest-vars.sh <==
# . these into your shell to allow you to run with socketwrapper
# outside the test environment

export UID_WRAPPER=1
export NSS_WRAPPER_PASSWD=$PWD/st/dc/passwd
export NSS_WRAPPER_GROUP=$PWD/st/dc/group
export CONFIGURATION="--configfile=$PWD/st/dc/etc/smb.conf"
export VAMPIRE_DC_SERVER=localvampiredc
export VAMPIRE_DC_SERVER_IP=127.0.0.22
export VAMPIRE_DC_NETBIOSNAME=localvampiredc1
export VAMPIRE_DC_NETBIOSALIAS=localvampiredc
export MEMBER_SERVER=localmember3
export MEMBER_SERVER_IP=127.0.0.23
export MEMBER_NETBIOSNAME=localmember3
export MEMBER_NETBIOSALIAS=localmember
export RPC_PROXY_SERVER=localrpcproxy4
export RPC_PROXY_SERVER_IP=127.0.0.24
export RPC_PROXY_NETBIOSNAME=localrpcproxy4
export RPC_PROXY_NETBIOSALIAS=localrpcproxy
export SELFTEST_MAXTIME=1200
export NETBIOSNAME=localdc1
export REALM=SAMBA.EXAMPLE.COM
export SOCKET_WRAPPER_DEFAULT_IFACE=21
export SERVER=localdc1
export SELFTEST_WINBINDD_SOCKET_DIR=$PWD/st/dc/winbindd_socket
export SELFTEST_PREFIX=$PWD/st
export DOMAIN=SAMBADOMAIN
export BINDIR=./bin
export DC_SERVER_IP=127.0.0.21
export SELFTEST_INTERFACES=127.0.0.6/8,127.0.0.7/8,127.0.0.8/8,127.0.0.9/8,127.0.0.10/8,127.0.0.11/8
export SOCKET_WRAPPER_DIR=$PWD/st/w
export DC_USERNAME=Administrator
export USERNAME=Administrator
export SERVER_IP=127.0.0.21
export KRB5_CONFIG=$PWD/st/dc/etc/krb5.conf
export PREFIX_ABS=$PWD/st
export SRCDIR_ABS=$PWD
export PREFIX=$PWD/st
export KRB5CCNAME=$PWD/st/krb5ticket
export SRCDIR=$PWD/
export TLS_ENABLED=yes
export DC_NETBIOSALIAS=localdc
export DC_NETBIOSNAME=localdc1
export DC_SERVER=localdc1
export DC_PASSWORD=locDCpass1
export PYTHONPATH=$PWD/bin/python
export PASSWORD=locDCpass1
export NETBIOSALIAS=localdc
export SMB_CONF_PATH=$PWD/st/dc/etc/smb.conf
